#
# spec file for package ghc-distributive
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name distributive
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.6.2.1
Release:        bp154.1.13
Summary:        Distributive functors -- Dual to Traversable
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-transformers-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-generic-deriving-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
Distributive functors -- Dual to 'Traversable'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%changelog
* Wed Aug  4 2021 psimons@suse.com
- Update distributive to version 0.6.2.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Dec 30 2020 psimons@suse.com
- Update distributive to version 0.6.2.1.
  0.6.2.1 [2020.12.30]
  - -------------------
  * The build-type has been changed from `Custom` to `Simple`.
    To achieve this, the `doctests` test suite has been removed in favor of using
    [`cabal-docspec`](https://github.com/phadej/cabal-extras/tree/master/cabal-docspec)
    to run the doctests.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update distributive to version 0.6.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update distributive to version 0.6.2.
  0.6.2 [2020.04.10]
  - -----------------
  * Make the `Distributive` instance for `Tagged` poly-kinded.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Sep  7 2019 psimons@suse.com
- Update distributive to version 0.6.1.
  0.6.1 [2019.09.06]
  - -----------------
  * Add a `Distributive` instance for `WrappedMonad m`.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update distributive to version 0.6.
  0.6 [2018.07.02]
  - ---------------
  * Remove `fmapCollect`. (See
    [here](https://github.com/ekmett/distributive/commit/1020655f15714514048d0dc842ffe4adcec89a7b)
    for an explanation of why it was removed.)
  * Avoid incurring some dependencies when using recent GHCs.
* Mon May 14 2018 psimons@suse.com
- Update distributive to version 0.5.3 revision 5.
  * Support `doctest-0.12`
  * Revamp `Setup.hs` to use `cabal-doctest`. This makes `distributive` build
    with `Cabal-1.25`, and makes the `doctest`s work with `cabal new-build` and
    sandboxes.
  * Fix bugs in `Data.Distributive.Generic` that cause generic `Distributive`
    instances not to work properly for datatypes with recursive types
  * Add `genericCollect` to `Data.Distributive.Generic`, and switch the underlying
    machinery in that module to work on a `collect`-like method instead of a
    `distribute`-like one
  * Add a test suite for regression-testing `Data.Distributive.Generic`
* Sun Feb  5 2017 psimons@suse.com
- Update to version 0.5.2 revision 2 with cabal2obs.
* Mon Jan  9 2017 psimons@suse.com
- Update to version 0.5.1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.5.0.2 revision 0 with cabal2obs.
* Tue Jan 26 2016 mimi.vx@gmail.com
- update to 0.5.0.2
  * Added flags for removing some dependencies.
  * upport doctests when building to non-standard locations (such as when using stack.)
  * Support base-orphans
* Thu May 21 2015 mimi.vx@gmail.com
- correct licence to BSD-2-Clause
* Sun Apr 26 2015 mimi.vx@gmail.com
- initial commit
